==> payara-embedded-all-5.201-sources.jar: com/sun/enterprise/config/serverbeans/customvalidators/JavaClassNameValidator.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2009-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.config.serverbeans.customvalidators;

import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;

/**
 * Implementation for the user-defined constraint annotation @JavaClassName 
 * @author Nandini Ektare
 */
public class JavaClassNameValidator
implements ConstraintValidator<JavaClassName, String> {

    @Override
    public void initialize(final JavaClassName fqcn) {}

    @Override
    public boolean isValid(final String fullyQualifiedClassName,                
        final ConstraintValidatorContext constraintValidatorContext) {

        try {
            return isValidPackageName(fullyQualifiedClassName);
        } catch (Exception e) {
            return false;
        }
    }

    /** Is the given string a valid package name? */
    private boolean isValidPackageName(String fqcn) {
        int index;

        if (fqcn.indexOf('.') == -1) {
            return isValidClassName(fqcn);
        }

        while ((index = fqcn.indexOf('.')) != -1) {
            if (!isValidClassName(fqcn.substring(0, index))) {
                return false;
            }
            fqcn = fqcn.substring(index+1);
        }
        return isValidClassName(fqcn);
    }

    private boolean isValidClassName(String className) {
        boolean valid = true;
        for(int i=0;i<className.length();i++) {
            if(i == 0) {
                if(!Character.isJavaIdentifierStart(className.charAt(i)))
                    valid = false;
            }
            if(!Character.isJavaIdentifierPart(className.charAt(i)))
                valid = false;
        }
        return valid;
    }
}

==> payara-embedded-all-6.2023.8-sources.jar: com/sun/enterprise/config/serverbeans/customvalidators/JavaClassNameValidator.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2009-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.config.serverbeans.customvalidators;

import jakarta.validation.ConstraintValidator;
import jakarta.validation.ConstraintValidatorContext;

/**
 * Implementation for the user-defined constraint annotation @JavaClassName 
 * @author Nandini Ektare
 */
public class JavaClassNameValidator
implements ConstraintValidator<JavaClassName, String> {

    @Override
    public void initialize(final JavaClassName fqcn) {}

    @Override
    public boolean isValid(final String fullyQualifiedClassName,                
        final ConstraintValidatorContext constraintValidatorContext) {

        try {
            return isValidPackageName(fullyQualifiedClassName);
        } catch (Exception e) {
            return false;
        }
    }

    /** Is the given string a valid package name? */
    private boolean isValidPackageName(String fqcn) {
        int index;

        if (fqcn.indexOf('.') == -1) {
            return isValidClassName(fqcn);
        }

        while ((index = fqcn.indexOf('.')) != -1) {
            if (!isValidClassName(fqcn.substring(0, index))) {
                return false;
            }
            fqcn = fqcn.substring(index+1);
        }
        return isValidClassName(fqcn);
    }

    private boolean isValidClassName(String className) {
        boolean valid = true;
        for(int i=0;i<className.length();i++) {
            if(i == 0) {
                if(!Character.isJavaIdentifierStart(className.charAt(i)))
                    valid = false;
            }
            if(!Character.isJavaIdentifierPart(className.charAt(i)))
                valid = false;
        }
        return valid;
    }
}
